@@ -1,6 +1,6 @@
 # coding: utf-8
 """
-iffSamples API package
+SampleDB API package
 """
 
 from . import server
