@@ -8,13 +8,14 @@ import typing
 
 import flask
 import flask_login
+from flask_babel import _
 from flask_wtf import FlaskForm
 
 from wtforms.fields import IntegerField
 from wtforms.validators import InputRequired
 
 from .. import frontend
-from ...logic import errors, users, groups, projects, object_permissions, locations, instrument_log_entries, instruments
+from ...logic import errors, users, groups, projects, object_permissions, locations, instrument_log_entries, instruments, instrument_translations
 from ...logic.notifications import get_notification, get_notifications, mark_notification_as_read, delete_notification, NotificationType
 
 
@@ -60,7 +61,7 @@ def notifications(user_id):
                     delete_notification(notification.id)
                 except errors.NotificationDoesNotExistError:
                     continue
-        flask.flash('The notifications have been deleted.', 'success')
+        flask.flash(_('The notifications have been deleted.'), 'success')
         return flask.redirect(flask.url_for('.notifications', user_id=user_id))
 
     if mark_all_notifications_as_read_form.validate_on_submit():
@@ -72,7 +73,7 @@ def notifications(user_id):
                     mark_notification_as_read(notification.id)
                 except errors.NotificationDoesNotExistError:
                     continue
-        flask.flash('The notifications have been marked as read.', 'success')
+        flask.flash(_('The notifications have been marked as read.'), 'success')
         return flask.redirect(flask.url_for('.notifications', user_id=user_id))
 
     if delete_notification_form.validate_on_submit():
@@ -82,9 +83,9 @@ def notifications(user_id):
             if notification.user_id == flask_login.current_user.id:
                 delete_notification(notification_id)
         except errors.NotificationDoesNotExistError:
-            flask.flash('This notification does not exist.', 'error')
+            flask.flash(_('This notification does not exist.'), 'error')
         else:
-            flask.flash('The notification has been deleted.', 'success')
+            flask.flash(_('The notification has been deleted.'), 'success')
         return flask.redirect(flask.url_for('.notifications', user_id=user_id))
 
     if mark_notification_as_read_form.validate_on_submit():
@@ -94,9 +95,9 @@ def notifications(user_id):
             if notification.user_id == flask_login.current_user.id:
                 mark_notification_as_read(notification_id)
         except errors.NotificationDoesNotExistError:
-            flask.flash('This notification does not exist.', 'error')
+            flask.flash(_('This notification does not exist.'), 'error')
         else:
-            flask.flash('The notification has been marked as read.', 'success')
+            flask.flash(_('The notification has been marked as read.'), 'success')
         return flask.redirect(flask.url_for('.notifications', user_id=user_id))
 
     notifications = get_notifications(user_id)
@@ -118,6 +119,7 @@ def notifications(user_id):
         is_group_member=_is_group_member,
         get_project=_safe_get_project,
         get_instrument=_safe_get_instrument,
+        get_instrument_with_translation_in_language=_safe_get_instrument_with_translation_in_language,
         get_instrument_log_entry=_safe_get_instrument_log_entry,
         is_project_member=_is_project_member,
         get_user_object_permissions=object_permissions.get_user_object_permissions,
@@ -167,3 +169,15 @@ def _safe_get_instrument_log_entry(instrument_log_entry_id: int) -> typing.Optio
         return instrument_log_entries.get_instrument_log_entry(instrument_log_entry_id)
     except errors.InstrumentLogEntryDoesNotExistError:
         return None
+
+
+def _safe_get_instrument_with_translation_in_language(
+        instrument_id: int,
+        language_id: int
+) -> typing.Optional[instruments.Instrument]:
+    try:
+        return instrument_translations.get_instrument_with_translation_in_language(instrument_id, language_id)
+    except errors.InstrumentDoesNotExistError:
+        return None
+    except errors.InstrumentTranslationDoesNotExistError:
+        return None
